aboutsummaryrefslogtreecommitdiffstats
path: root/Software/PMR/Messages
diff options
context:
space:
mode:
authorRoy Ben Shabat <Roy.mail.net@gmail.com>2025-07-13 14:58:37 +0300
committerRoy Ben Shabat <Roy.mail.net@gmail.com>2025-07-13 14:58:37 +0300
commit190d61e456b0ff05cf84121af0d186c975d6682a (patch)
tree3f653d469d7f9df3699c8240bb3918869ca049ee /Software/PMR/Messages
parente528e98507e3822edb20390d95716f0385c5b826 (diff)
downloadTango-190d61e456b0ff05cf84121af0d186c975d6682a.tar.gz
Tango-190d61e456b0ff05cf84121af0d186c975d6682a.zip
Added new tech monitors and ios.
Diffstat (limited to 'Software/PMR/Messages')
-rw-r--r--Software/PMR/Messages/Diagnostics/DiagnosticsMonitors.proto9
-rw-r--r--Software/PMR/Messages/Diagnostics/EventType.proto26
-rw-r--r--Software/PMR/Messages/Diagnostics/InterfaceIOs.proto15
-rw-r--r--Software/PMR/Messages/Insights/InsightsMonitors.proto9
4 files changed, 55 insertions, 4 deletions
diff --git a/Software/PMR/Messages/Diagnostics/DiagnosticsMonitors.proto b/Software/PMR/Messages/Diagnostics/DiagnosticsMonitors.proto
index f53f6a5b7..f42f4e907 100644
--- a/Software/PMR/Messages/Diagnostics/DiagnosticsMonitors.proto
+++ b/Software/PMR/Messages/Diagnostics/DiagnosticsMonitors.proto
@@ -798,4 +798,13 @@ message DiagnosticsMonitors
//Eureka Pump 5 Card Temperature (Min = 0, Max = 100, PPF = 10)
repeated double EuPump5CardTemperature = 260;
+ //Eureka Waste Jerrican Weight (Min = 0, Max = 5000, PPF = 1)
+ repeated double EuWasteJerricanWeight = 261;
+
+ //Eureka Waste Front Pump Current (Min = 0, Max = 1000, PPF = 1)
+ repeated double EuWasteFrontPumpCurrent = 262;
+
+ //Eureka Waste Rear Pump Current (Min = 0, Max = 1000, PPF = 1)
+ repeated double EuWasteRearPumpCurrent = 263;
+
}
diff --git a/Software/PMR/Messages/Diagnostics/InterfaceIOs.proto b/Software/PMR/Messages/Diagnostics/InterfaceIOs.proto
index a80ca9acc..db28c3c64 100644
--- a/Software/PMR/Messages/Diagnostics/InterfaceIOs.proto
+++ b/Software/PMR/Messages/Diagnostics/InterfaceIOs.proto
@@ -1279,4 +1279,19 @@ enum InterfaceIOs
//Designator: X4GPI204
SafetyCirculatorAirflow = 420;
+ //Designator: X4GPI400
+ BlockSubtanks = 421;
+
+ //Designator: X4GPO400
+ WasteSystemError = 422;
+
+ //Designator: X4GPO401
+ WasteJerricanPresence = 423;
+
+ //Designator: X4GPO402
+ FrontSubtankFull = 424;
+
+ //Designator: X4GPO403
+ RearSubtankFull = 425;
+
}
diff --git a/Software/PMR/Messages/Insights/InsightsMonitors.proto b/Software/PMR/Messages/Insights/InsightsMonitors.proto
index 3a30f036f..b0e7176f3 100644
--- a/Software/PMR/Messages/Insights/InsightsMonitors.proto
+++ b/Software/PMR/Messages/Insights/InsightsMonitors.proto
@@ -796,4 +796,13 @@ message InsightsMonitors
//Eureka Pump 5 Card Temperature
double EuPump5CardTemperature = 260;
+ //Eureka Waste Jerrican Weight
+ double EuWasteJerricanWeight = 261;
+
+ //Eureka Waste Front Pump Current
+ double EuWasteFrontPumpCurrent = 262;
+
+ //Eureka Waste Rear Pump Current
+ double EuWasteRearPumpCurrent = 263;
+
}
diff --git a/Software/PMR/Messages/Diagnostics/EventType.proto b/Software/PMR/Messages/Diagnostics/EventType.proto
index 32031039f..bf56d5ade 100644
--- a/Software/PMR/Messages/Diagnostics/EventType.proto
+++ b/Software/PMR/Messages/Diagnostics/EventType.proto
@@ -1447,6 +1447,9 @@ enum EventType
//Communication error. Cannot execute job (Group = GeneralHardware, Category = Error)
E_NO_COMMUNICATION_WITH_IDS_5_BOARD = 105022;
+ //No communication with waste load cell. Cannot execute job (Group = GeneralHardware, Category = Error)
+ E_NO_COMMUNICATION_WITH_WASTE_LOADCELL = 105023;
+
//Left door is open (Group = GeneralHardware, Category = Warning)
E_LEFT_DOOR_OPEN = 106000;
@@ -2122,10 +2125,25 @@ enum EventType
//Waste jerrycan and sub-tanks are full. Cannot execute job (Group = WasteHandlingSystem, Category = Error)
E_WASTE_JERRYCAN_AND_SUB_TANKS_ARE_FULL = 113002;
- //No draining from IDU-Chimney sub-tank. Cannot execute job (Group = WasteHandlingSystem, Category = Error)
- E_NO_DRAINING_FROM_IDU_CHIMNEY_SUB_TANK = 113003;
+ //No draining from IDU-Chimney sub-tank due to timeout. Cannot execute job (Group = WasteHandlingSystem, Category = Error)
+ E_NO_DRAINING_FROM_IDU_CHIMNEY_SUB_TANK_TIMEOUT = 113003;
+
+ //No draining from IFS-Dryer sub-tank due to timeout. Cannot execute job (Group = WasteHandlingSystem, Category = Error)
+ E_NO_DRAINING_FROM_IFS_DRYER_SUB_TANK_TIMEOUT = 113004;
+
+ //No draining from IDU-Chimney sub-tank due to emptying issue. Cannot execute job (Group = WasteHandlingSystem, Category = Error)
+ E_NO_DRAINING_FROM_IDU_CHIMNEY_SUB_TANK_ISSUE = 113005;
+
+ //No draining from IFS-Dryer sub-tank due to emptying issue. Cannot execute job (Group = WasteHandlingSystem, Category = Error)
+ E_NO_DRAINING_FROM_IFS_DRYER_SUB_TANK_ISSUE = 113006;
+
+ //IDU-Chimney sub-tank pump malfunction. Cannot execute job (Group = WasteHandlingSystem, Category = Error)
+ E_IDU_CHIMNEY_SUB_TANK_PUMP_MALFUNCTION = 113007;
+
+ //IFS-Dryer sub-tank pump malfunction. Cannot execute job (Group = WasteHandlingSystem, Category = Error)
+ E_IFS_DRYER_SUB_TANK_PUMP_MALFUNCTION = 113008;
- //No draining from IFS-Dryer sub-tank. Cannot execute job (Group = WasteHandlingSystem, Category = Error)
- E_NO_DRAINING_FROM_IFS_DRYER_SUB_TANK = 113004;
+ //Waste jerrycan presence switch malfunction. Cannot execute job (Group = WasteHandlingSystem, Category = Error)
+ E_WASTE_JERRYCAN_PRESENCE_SWITCH_MALFUNCTION = 113009;
}